within FluidDissipation.Utilities.Functions.General;
function ReynoldsNumber "calculation of Reynolds number"

  import SI = Modelica.SIunits;
  import MIN = Modelica.Constants.eps;

  //geometry
  input SI.Area A_cross "Cross sectional area";
  input SI.Length perimeter "Wetted perimeter";

  //fluid properties
  input SI.Density rho "Density of fluid";
  input SI.DynamicViscosity eta "Dynamic viscosity of fluid";

  input SI.MassFlowRate m_flow "Mass flow rate";

  output SI.ReynoldsNumber Re "Reynolds number";
  output SI.Velocity velocity "Mean velocity";

protected
  SI.Diameter d_hyd=4*A_cross/max(MIN, perimeter) "Hydraulic diameter";

algorithm
  Re := 4*abs(m_flow)/max(MIN, (perimeter*eta));
  velocity := m_flow/max(MIN, (rho*A_cross));
  annotation (smoothOrder=1);
end ReynoldsNumber;
